AnalysisResult class

Result returned after analysing a File analyze.

Constructors

AnalysisResult({required AbstractType? parent, Set<CustomType> childrenCustomTypes = const {}, Set<EnumType> childrenEnumTypes = const {}})
Construct a new AnalysisResult.
const

Properties

childrenCustomTypes → Set<CustomType>
All CustomType members.
final
childrenEnumTypes → Set<EnumType>
All EnumType members.
final
hashCode → int
The hash code for this object.
no setterinherited
parent → AbstractType?
Main CustomType or EnumType.
final
parentAsCustomTypeOrFail → CustomType
Get the parent as CustomType.
no setter
parentAsEnumTypeOrFail → EnumType
Get the parent as EnumType.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited