BracketCounter class decoder

Utility to count brackets and determine which content is inside the same bracket pairs.

This is used to split a JSON String into smaller chunks, which makes it easier to determine List sizes, total depth etc.

Constructors

BracketCounter({required List<String> characters, required int startIndex, required String openingBracket, required String closingBracket})
Construct a new instance.

Properties

characters → List<String>
List of characters to be processed.
final
closingBracket → String
Type of closing bracket, e.g. ']' or '}'.
final
contentBetweenBrackets → List<String>
List of all characters between opening and closing bracket.
no setter
endIndex → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
openingBracket → String
Type of opening bracket, e.g. '[' or ''{.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndex → int
Index of String where processing should start.
final
totalDepth → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited