Float64ListType class ast

A Float64List StandardType.

Inheritance
Implementers
Available extensions

Constructors

Float64ListType()
Construct a new Float64ListType.
const

Properties

className → String
Name of this class.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
nullable → bool
Bool indicator if null is allowed.
no setteroverride
printDecoderMethod → String

Available on AbstractType, provided by the DecoderMethod extension

Output decoding method line.
no setter
printType → String

Available on AbstractType, provided by the AbstractTypeSerializer extension

Output AbstractType as dart code.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

normalizeType(Set<EnumType> enumTypes, Set<CustomType> customTypes) → AbstractType

Available on AbstractType, provided by the AbstractTypeNormalizer extension

Normalize AbstractType by replacing any (nested Type) with the instance scanned by the analyzer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
unwrapNestedTypes() → List<AbstractType>

Available on AbstractType, provided by the NestedTypeFinder extension

Find nested AbstractType.

Operators

operator ==(Object other) → bool
The equality operator.
inherited