JsonEncode<T> class decoder encoder

Encode a (non-standard) dart type to a JsonNode.

Constructors

JsonEncode({required JsonNode using(T t)})
Configure JsonEncode to encode a value using.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
using → JsonNode Function(T t)
Function to convert data of type T to a JsonNode.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited