JsonFormattingOptions class encoder

Options to configure JSON formatting.

Available extensions

Constructors

JsonFormattingOptions({required int indentation, required int colonPadding})
Construct a JsonFormattingOptions instance.
const

Properties

colonPadding → int
Padding size arround colons.
final
hashCode → int
The hash code for this object.
no setterinherited
indentation → int
Length of indentation per level.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({JsonIndentationSize? indentationSize, int? indentationSizeInt, int? colonPadding}) → JsonFormattingOptions

Available on JsonFormattingOptions, provided by the JsonFormattingOptionsBuilder extension

Build a new JsonFormattingOptions instance by using an existing JsonFormattingOptions instance as base.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited