JsonIntegerNumberOrNull class ast decoder encoder

A JSON element containing an int value or null.

Example:

{"friends":0}

key = friends data = 0

Inheritance

Constructors

JsonIntegerNumberOrNull({required String key, required int? data})
Construct a new JsonIntegerNumberOrNull instance.
const
JsonIntegerNumberOrNull.parse({required String key, required String? data})
Construct a new JsonIntegerNumberOrNull instance by parsing the data as int value.
factory

Properties

annotations → List<TypeAnnotation>
Metadata annotations which alter (de)serialization of this node.
finalinherited
data → int?
The JSON data of type T.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → String
The JSON key (tag name).
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → String
Convert to formatted JSON String.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited