JsonMap<T> class

A JsonObject which children are all of the same type.

When all children are of the same type then a JSON node can be deserialized as Map with strongly typed children. This is mostly useful when a Map is nested inside one or more Lists.

Inheritance

Constructors

JsonMap({required String key, required Map<String, JsonNode<T>> data})
Create a new JsonMap.
const

Properties

annotations → List<TypeAnnotation>
Metadata annotations which alter (de)serialization of this node.
finalinherited
data → Map<String, JsonNode<T>>
The JSON data of type T.
finalinherited
dataTyped → Map<String, T>
Return raw (unwrapped) object data as Map where R is not of type JsonNode but a dart StandardType (String, bool, etc).
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → String
The JSON key (tag name).
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → String
Convert to (standard) formatted JSON String.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited