JsonString class ast decoder encoder

A JSON element containing a String value.

Example:

{"name":"Luke Skywalker"}

key = name data = Luke Skywalker

Inheritance

Constructors

JsonString({required String key, required String data})
Construct a new JsonString instance.
const

Properties

annotations → List<TypeAnnotation>
Metadata annotations which alter (de)serialization of this node.
finalinherited
data → String
The JSON data of type T.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → String
The JSON key (tag name).
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → String
Convert to formatted JSON String.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited