JsonValue class decoder encoder

Set value of field with value of JsonNode with name.

Constructors

JsonValue(String name)
Configure JsonValue to use this name tag.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Json tag to retrieve.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited