SquintGeneratorOptions class generator

Options to configure code generation.

Available extensions

Constructors

SquintGeneratorOptions({required bool includeJsonAnnotations, required bool alwaysAddJsonValue, required bool blankLineBetweenFields, required bool generateChildClasses, required bool includeCustomTypeImports})
Construct a SquintGeneratorOptions instance.
const

Properties

alwaysAddJsonValue → bool generator
Is ignored when includeJsonAnnotations is set to false.
final
blankLineBetweenFields → bool generator
Add a blank line between data class fields.
final
generateChildClasses → bool
Configure to generate child classes or not.
final
hashCode → int
The hash code for this object.
no setterinherited
includeCustomTypeImports → bool
Configure to add import statements for each TypeMember CustomType/EnumType.
final
includeJsonAnnotations → bool generator
Include @JsonValue, @JsonEncode and @JsonDecode annotations on generated data classes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? includeJsonAnnotations, bool? alwaysAddJsonValue, bool? blankLineBetweenFields, bool? generateChildClasses, bool? includeCustomTypeImports}) → SquintGeneratorOptions generator

Available on SquintGeneratorOptions, provided by the SquintGeneratorOptionsBuilder extension

Copy the standardSquintGeneratorOptions with custom overrides.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited