StringUtils extension

String processing utilities.

on

Properties

format → String

Available on String, provided by the StringUtils extension

Utility to print templated Strings.
no setter
formattedDartCode → String

Available on String, provided by the StringUtils extension

Format a String as dart code using dart_style DartFormatter.
no setter
snakeCase → String

Available on String, provided by the StringUtils extension

Convert a String to snake_case
no setter

Methods

camelCase({bool capitalize = true}) → String

Available on String, provided by the StringUtils extension

Convert a String to camelcase.
removePostfixIfPresent(String toRemove) → String

Available on String, provided by the StringUtils extension

Remove the postfix of a String if present or return current String.
removePrefixIfPresent(String toRemove) → String

Available on String, provided by the StringUtils extension

Remove the prefix of a String if present or return current String.