TypeAnnotation class ast

Annotation data.

Constructors

TypeAnnotation({required String name, Map<String, String> data = const <String, String>{}})
Construct a new TypeAnnotation.
const

Properties

data → Map<String, String>
All key-value data.
final
hashCode → int
The hash code for this object.
no setteroverride
name → String
Name of this annotation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override